@@ -12,6 +12,7 @@ from typing import (
     Any,
     Callable,
     Dict,
+    Generic,
     ItemsView,
     Iterable,
     Iterator,
@@ -20,12 +21,16 @@ from typing import (
     Optional,
     Set,
     Tuple,
+    TypeVar,
     Union,
 )
 
-from jsonbourne import json
+from jsonbourne import jsonlib
 
 
+_KT = TypeVar("_KT")
+_VT = TypeVar("_VT")
+
 if sys.version_info < (3, 7):
     from collections.abc import MutableMapping
 
@@ -33,7 +38,7 @@ if sys.version_info < (3, 7):
 else:
     from typing import MutableMapping
 
-    JsonObjMutableMapping = MutableMapping[str, Any]
+    JsonObjMutableMapping = MutableMapping[str, _VT]
 
 __all__ = [
     "JsonObj",
@@ -109,10 +114,10 @@ def is_int(value: Any) -> bool:
     """Return True if value is a int"""
     if isinstance(value, int):
         return True
-    value = str(value)
-    if value[0] in ('-', '+'):
-        return value[1:].isdigit()
-    return value.isdigit()
+    _value: str = str(value)
+    if _value[0] in ('-', '+'):
+        return str(_value[1:]).isdigit()
+    return _value.isdigit()
 
 
 def is_number(value: Any) -> bool:
@@ -120,7 +125,7 @@ def is_number(value: Any) -> bool:
     return is_int(value) or is_float(value)
 
 
-class JsonObj(JsonObjMutableMapping):
+class JsonObj(JsonObjMutableMapping, Generic[_VT]):
     """JSON friendly python dictionary with dot notation and string only keys
 
     JsonObj(foo='bar')['foo'] == JsonObj(foo='bar').foo
@@ -189,7 +194,7 @@ class JsonObj(JsonObjMutableMapping):
 
     """
 
-    _data: Dict[str, Any]
+    _data: Dict[str, _VT]
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Use the object dict"""
@@ -371,7 +376,7 @@ class JsonObj(JsonObjMutableMapping):
         """Return the keys view of the JsonObj object"""
         return self._data.keys()
 
-    def setdefault(self, key: Any, default: Optional[Any] = None) -> None:
+    def setdefault(self, key: str, default: Optional[_VT] = None) -> _VT:
         if default:
             return self._data.setdefault(key, default)
         return self._data.setdefault(key)
@@ -686,7 +691,7 @@ class JsonObj(JsonObjMutableMapping):
                 pformat(self.to_dict(), width=width)[1:-1].replace("\n", "\n   "),
                 "\n})",
             ]
-        )
+        ).replace('JsonObj(**{}),', '{},')
 
     def __repr__(self) -> str:
         """Return the string representation of the object"""
@@ -822,7 +827,7 @@ class JsonObj(JsonObjMutableMapping):
             JsonObj: JsonObj object for the given JSON string
 
         """
-        return cls.from_dict(json.loads(json_string))
+        return cls.from_dict(jsonlib.loads(json_string))
 
     def to_json(
         self, pretty: bool = False, sort_keys: bool = False, **kwargs: Any
@@ -872,7 +877,9 @@ class JsonObj(JsonObjMutableMapping):
             str: JSON string of the JsonObj object
 
         """
-        return json.dumps(self.to_dict(), pretty=pretty, sort_keys=sort_keys, **kwargs)
+        return jsonlib.dumps(
+            self.to_dict(), pretty=pretty, sort_keys=sort_keys, **kwargs
+        )
 
     @classmethod
     def validate_type(cls, val: Any) -> "JsonObj":
@@ -901,7 +908,7 @@ def jsonify(value: Any) -> Any:
         return tuple([jsonify(el) for el in value])
     if isinstance(value, str):
         try:
-            data = json.loads(value)
+            data = jsonlib.loads(value)
             return jsonify(data)
         except Exception:
             pass
@@ -949,7 +956,7 @@ class JSON(metaclass=JSONMeta):
     ) -> str:
         """Return JSON stringified/dumps-ed data"""
         return str(
-            json.dumps(
+            jsonlib.dumps(
                 data, pretty=pretty, sort_keys=sort_keys, default=default, **kwargs
             )
         )
@@ -964,7 +971,7 @@ class JSON(metaclass=JSONMeta):
     ) -> str:
         """Return JSON stringified/dumps-ed data"""
         return str(
-            json.dumps(
+            jsonlib.dumps(
                 data, pretty=pretty, sort_keys=sort_keys, default=default, **kwargs
             )
         )
@@ -979,7 +986,7 @@ class JSON(metaclass=JSONMeta):
     ) -> bytes:
         """Return JSON string bytes for given data"""
         return bytes(
-            json.dumpb(
+            jsonlib.dumpb(
                 data, pretty=pretty, sort_keys=sort_keys, default=default, **kwargs
             )
         )
@@ -994,7 +1001,7 @@ class JSON(metaclass=JSONMeta):
     ) -> bytes:
         """Return JSON string bytes for given data"""
         return bytes(
-            json.dumpb(
+            jsonlib.dumpb(
                 data, pretty=pretty, sort_keys=sort_keys, default=default, **kwargs
             )
         )
@@ -1003,37 +1010,37 @@ class JSON(metaclass=JSONMeta):
     def loads(string: str, obj: bool = False, **kwargs: Any) -> Any:
         """Parse JSON string/bytes and return raw representation"""
         if obj:
-            return jsonify(json.loads(string, **kwargs))
-        return json.loads(string, **kwargs)
+            return jsonify(jsonlib.loads(string, **kwargs))
+        return jsonlib.loads(string, **kwargs)
 
     @staticmethod
     def parse(string: str, obj: bool = True) -> Any:
         """Parse JSON string/bytes and jsonify all dictionaries -> JsonObj"""
         if obj:
-            return jsonify(json.loads(string))
-        return json.loads(string)
+            return jsonify(jsonlib.loads(string))
+        return jsonlib.loads(string)
 
     @staticmethod
     def use_orjson() -> None:
-        json.use_orjson()
+        jsonlib.use_orjson()
 
     @staticmethod
     def use_rapidjson() -> None:
-        json.use_rapidjson()
+        jsonlib.use_rapidjson()
 
     @staticmethod
     def use_json_stdlib() -> None:
-        json.use_json_stdlib()
+        jsonlib.use_json_stdlib()
 
     @staticmethod
     def which() -> str:
         """Return the name of the JSON library being used as a backend"""
-        return json.which()
+        return jsonlib.which()
 
     @staticmethod
     def json_lib() -> str:
         """Return the name of the JSON library being used as a backend"""
-        return json.which()
+        return jsonlib.which()
 
     @staticmethod
     def jsonify(value: Any) -> Any:
