@@ -10,7 +10,7 @@ __all__ = ["rm_js_comments", "strip_comments"]
 STRIP_JSON_COMMENTS_REGEX = r"(\".*?(?<!\\)\"|\'.*?(?<!\\)\')|(/\*.*?\*/|//[^\r\n]*$)"
 
 
-def _strip_json_comments_regex_replacer(match: Match) -> str:  # type: ignore
+def _strip_json_comments_regex_replacer(match: Match[str]) -> str:  # type: ignore
     # if the 2nd group (capturing comments) is not None,
     # it means we have captured a non-quoted (real) comment string.
     if match.group(2) is not None:
@@ -32,4 +32,5 @@ def rm_js_comments(string: str) -> str:
 
 
 def strip_comments(string: str) -> str:
+
     return rm_js_comments(string)
